@@ -15,6 +15,8 @@
 #include "timeutil.h"
 #include "../libversit/vcc.h"
 
+extern CalendarAlarm alarm_defaults[4];
+
 static char *
 ical_gen_uid (void)
 {
@@ -52,6 +54,9 @@ ical_object_new (void)
 	ico->seq = -1;
 	ico->dtstamp = time (NULL);
 	ico->uid = ical_gen_uid ();
+
+	ico->pilot_id = 0;
+	ico->pilot_status = ICAL_PILOT_SYNC_MOD;
 	
 	return ico;
 }
@@ -59,19 +64,12 @@ ical_object_new (void)
 static void
 default_alarm (iCalObject *ical, CalendarAlarm *alarm, char *def_mail, enum AlarmType type)
 {
-	alarm->enabled = 0;
-	alarm->type    = type;
-
-	if (type != ALARM_MAIL){
-		alarm->count   = 15;
-		alarm->units   = ALARM_MINUTES;
-	} else {
-		alarm->count   = 1;
-		alarm->units   = ALARM_DAYS;
-	}
-
-	if (type == ALARM_MAIL)
-		alarm->data = g_strdup (def_mail);
+	alarm->type = type;
+	alarm->enabled = alarm_defaults[type].enabled;
+	alarm->count = alarm_defaults[type].count;
+	alarm->units = alarm_defaults[type].units;
+	if (alarm_defaults[type].data)
+		alarm->data = g_strdup (alarm_defaults[type].data);
 	else
 		alarm->data = g_strdup ("");
 }
@@ -377,6 +375,8 @@ load_recur_yearly_day (iCalObject *o, char **str)
 {
 	/* Skip as we do not support multiple days and we do expect
 	 * the dtstart to agree with the value on this field
+	 *
+	 * FIXME: we should support every-n-years
 	 */
 	skip_numbers (str);
 }
@@ -590,8 +590,10 @@ ical_object_create_from_vobject (VObject *o, const char *object_name)
 	if (has (o, VCUniqueStringProp)){
 		ical->uid = g_strdup (str_val (vo));
 		free (the_str);
+	} else {
+		ical->uid = ical_gen_uid ();
 	}
-	
+
 	/* seq */
 	if (has (o, VCSequenceProp)){
 		ical->seq = atoi (str_val (vo));
@@ -785,6 +787,22 @@ ical_object_create_from_vobject (VObject *o, const char *object_name)
 		}
 		free (the_str);
 	}
+
+	/*
+	 * Pilot
+	 */
+	if (has (o, XPilotIdProp)){
+		ical->pilot_id = atoi (str_val (vo));
+		free (the_str);
+	} else
+		ical->pilot_id = 0;
+
+	if (has (o, XPilotStatusProp)){
+		ical->pilot_status = atoi (str_val (vo));
+		free (the_str);
+	} else
+		ical->pilot_status = ICAL_PILOT_SYNC_MOD;
+	
 	return ical;
 }
 
@@ -1050,6 +1068,17 @@ ical_object_to_vobject (iCalObject *ical)
 		addPropValue (alarm, VCProcedureNameProp, ical->palarm.data);
 	if ((alarm = save_alarm (o, &ical->malarm, ical)))
 		addPropValue (alarm, VCEmailAddressProp, ical->malarm.data);
+
+	/* Pilot */
+	{
+		char buffer [20];
+		
+		sprintf (buffer, "%d", ical->pilot_id);
+		addPropValue (o, XPilotIdProp, buffer);
+		sprintf (buffer, "%d", ical->pilot_status);
+		addPropValue (o, XPilotStatusProp, buffer);
+	}
+	
 	return o;
 }
 
@@ -1429,3 +1458,33 @@ alarm_compute_offset (CalendarAlarm *a)
 	}
 	return a->offset;
 }
+
+iCalObject *
+ical_object_new_from_string (const char *vcal_string)
+{
+	iCalObject *ical = NULL;
+	VObject *cal, *event;
+	VObjectIterator i;
+	const char *object_name;
+	
+	cal = Parse_MIME (vcal_string, strlen (vcal_string));
+
+	initPropIterator (&i, cal);
+
+	while (moreIteration (&i)){
+		event = nextVObject (&i);
+
+		object_name = vObjectName (event);
+		
+		if (strcmp (object_name, VCEventProp) == 0){
+			ical = ical_object_create_from_vobject (event, object_name);
+			break;
+		}
+	}
+
+	cleanVObject (cal);
+	cleanStrTbl ();
+
+	return ical;
+}
+
