@@ -18,6 +18,7 @@
 #include "year-view.h"
 #include "timeutil.h"
 #include "main.h"
+#include "corba-cal.h"
 
 GnomeApp *parent_class;
 
@@ -44,11 +45,10 @@ gnome_calendar_get_type (void)
 static void
 setup_widgets (GnomeCalendar *gcal)
 {
-	GtkWidget *sw;
 	time_t now;
 
 	now = time (NULL);
-	
+
 	gcal->notebook   = gtk_notebook_new ();
 	gcal->day_view   = gncal_day_panel_new (gcal, now);
 	gcal->week_view  = gncal_week_view_new (gcal, now);
@@ -60,11 +60,13 @@ setup_widgets (GnomeCalendar *gcal)
 					GTK_POLICY_NEVER,
 					GTK_POLICY_AUTOMATIC);
 	gtk_container_add (GTK_CONTAINER (gcal->year_view_sw), gcal->year_view);
+	GTK_LAYOUT (gcal->year_view)->vadjustment->step_increment = 10.0;
+	gtk_adjustment_changed (GTK_ADJUSTMENT (GTK_LAYOUT (gcal->year_view)->vadjustment));
 
 	gtk_notebook_append_page (GTK_NOTEBOOK (gcal->notebook), gcal->day_view,   gtk_label_new (_("Day View")));
 	gtk_notebook_append_page (GTK_NOTEBOOK (gcal->notebook), gcal->week_view,  gtk_label_new (_("Week View")));
 	gtk_notebook_append_page (GTK_NOTEBOOK (gcal->notebook), gcal->month_view, gtk_label_new (_("Month View")));
-	gtk_notebook_append_page (GTK_NOTEBOOK (gcal->notebook), gcal->year_view_sw,  gtk_label_new (_("Year View"))); 
+	gtk_notebook_append_page (GTK_NOTEBOOK (gcal->notebook), gcal->year_view_sw,  gtk_label_new (_("Year View")));
 
 	gtk_widget_show_all (gcal->notebook);
 
@@ -132,7 +134,7 @@ gnome_calendar_direction (GnomeCalendar *gcal, int direction)
 {
 	GtkWidget *cp = get_current_page (gcal);
 	time_t new_time;
-	
+
 	if (cp == gcal->day_view)
 		new_time = time_add_day (time_day_begin (gcal->current_display), 1 * direction);
 	else if (cp == gcal->week_view)
@@ -183,7 +185,7 @@ gnome_calendar_goto_today (GnomeCalendar *gcal)
 {
 	g_return_if_fail (gcal != NULL);
 	g_return_if_fail (GNOME_IS_CALENDAR (gcal));
-	
+
 	gnome_calendar_goto (gcal, time (NULL));
 }
 
@@ -195,7 +197,7 @@ gnome_calendar_set_view (GnomeCalendar *gcal, char *page_name)
 	g_return_if_fail (gcal != NULL);
 	g_return_if_fail (GNOME_IS_CALENDAR (gcal));
 	g_return_if_fail (page_name != NULL);
-	
+
 
 	if (strcmp (page_name, "dayview") == 0)
 		page = 0;
@@ -214,19 +216,21 @@ gnome_calendar_new (char *title)
 	GtkWidget      *retval;
 	GnomeCalendar  *gcal;
 	GnomeApp       *app;
-		
+
 	retval = gtk_type_new (gnome_calendar_get_type ());
 	app = GNOME_APP (retval);
 	gcal = GNOME_CALENDAR (retval);
-	
+
 	app->name = g_strdup ("calendar");
 	app->prefix = g_strconcat ("/", app->name, "/", NULL);
-	
+
 	gtk_window_set_title(GTK_WINDOW(retval), title);
 
 	gcal->current_display = time_day_begin (time (NULL));
 	gcal->cal = calendar_new (title);
 	setup_widgets (gcal);
+	gnome_calendar_create_corba_server (gcal);
+
 	return retval;
 }
 
@@ -247,7 +251,7 @@ gnome_calendar_load (GnomeCalendar *gcal, char *file)
 	g_return_val_if_fail (gcal != NULL, 0);
 	g_return_val_if_fail (GNOME_IS_CALENDAR (gcal), 0);
 	g_return_val_if_fail (file != NULL, 0);
-	
+
 	if ((r = calendar_load (gcal->cal, file)) != NULL){
 		printf ("Error loading calendar: %s\n", r);
 		return 0;
@@ -315,12 +319,12 @@ execute (char *command, int close_standard)
 	struct sigaction ignore, save_intr, save_quit;
 	int status = 0, i;
 	pid_t pid;
-	
+
 	ignore.sa_handler = SIG_IGN;
 	sigemptyset (&ignore.sa_mask);
 	ignore.sa_flags = 0;
-    
-	sigaction (SIGINT, &ignore, &save_intr);    
+
+	sigaction (SIGINT, &ignore, &save_intr);
 	sigaction (SIGQUIT, &ignore, &save_quit);
 
 	if ((pid = fork ()) < 0){
@@ -333,16 +337,16 @@ execute (char *command, int close_standard)
 			const int top = max_open_files ();
 			sigaction (SIGINT,  &save_intr, NULL);
 			sigaction (SIGQUIT, &save_quit, NULL);
-			
+
 			for (i = (close_standard ? 0 : 3); i < top; i++)
 				close (i);
-			
+
 			/* FIXME: As an excercise to the reader, copy the
 			 * code from mc to setup shell properly instead of
 			 * /bin/sh.  Yes, this comment is larger than a cut and paste.
 			 */
 			execl ("/bin/sh", "/bin/sh", "-c", command, (char *) 0);
-			
+
 			_exit (127);
 		} else {
 			_exit (127);
@@ -359,7 +363,7 @@ mail_notify (char *mail_address, char *text, time_t app_time)
 	pid_t pid;
 	int   p [2];
 	char *command;
-	
+
 	pipe (p);
 	pid = fork ();
 	if (pid == 0){
@@ -383,27 +387,46 @@ mail_notify (char *mail_address, char *text, time_t app_time)
 }
 
 static void
-stop_beeping (GtkObject *object, gpointer tagp)
+stop_beeping (GtkObject* object, gpointer data)
 {
-	guint tag = GPOINTER_TO_INT (tagp);
-
-	gtk_timeout_remove (tag);
+	guint timer_tag, beep_tag;
+	timer_tag = GPOINTER_TO_INT (gtk_object_get_data (object, "timer_tag"));
+	beep_tag  = GPOINTER_TO_INT (gtk_object_get_data (object, "beep_tag"));
+	
+	if (beep_tag > 0) {
+		gtk_timeout_remove (beep_tag);
+		gtk_object_set_data (object, "beep_tag", GINT_TO_POINTER (0));
+	}
+	if (timer_tag > 0) {
+		gtk_timeout_remove (timer_tag);
+		gtk_object_set_data (object, "timer_tag", GINT_TO_POINTER (0));
+	}
 }
 
 static gint
 start_beeping (gpointer data)
 {
 	gdk_beep ();
-	
+
 	return TRUE;
 }
 
+static gint
+timeout_beep (gpointer data)
+{
+	stop_beeping (data, NULL);
+	return FALSE;
+}
+
 void
-calendar_notify (time_t time, CalendarAlarm *which, void *data)
+calendar_notify (time_t activation_time, CalendarAlarm *which, void *data)
 {
 	iCalObject *ico = data;
-	guint tag;
-		
+	guint beep_tag, timer_tag;
+	int ret;
+	gchar* snooze_button = (enable_snooze ? _("Snooze") : NULL);
+	time_t now, diff;
+
 	if (&ico->aalarm == which){
 		time_t app = ico->aalarm.trigger + ico->aalarm.offset;
 		GtkWidget *w;
@@ -414,11 +437,34 @@ calendar_notify (time_t time, CalendarAlarm *which, void *data)
 					ico->summary, "'", NULL);
 
 		/* Idea: we need Snooze option :-) */
-		w = gnome_message_box_new (msg, GNOME_MESSAGE_BOX_INFO, "Ok", NULL);
-		tag = gtk_timeout_add (1000, start_beeping, NULL);
-		gtk_signal_connect (GTK_OBJECT (w), "destroy", stop_beeping, GINT_TO_POINTER (tag));
-		gtk_widget_show (w);
-
+		w = gnome_message_box_new (msg, GNOME_MESSAGE_BOX_INFO, _("Ok"), snooze_button, NULL);
+		beep_tag = gtk_timeout_add (1000, start_beeping, NULL);
+		if (enable_aalarm_timeout)
+			timer_tag = gtk_timeout_add (audio_alarm_timeout*1000, 
+						     timeout_beep, w);
+		else
+			timer_tag = 0;
+		gtk_object_set_data (GTK_OBJECT (w), "timer_tag",
+				     GINT_TO_POINTER (timer_tag));
+		gtk_object_set_data (GTK_OBJECT (w), "beep_tag",
+				     GINT_TO_POINTER (beep_tag));
+		gtk_widget_ref (w);
+		ret = gnome_dialog_run (GNOME_DIALOG (w));
+		switch (ret) {
+		case 1:
+			stop_beeping (GTK_OBJECT (w), NULL);
+			now = time (NULL);
+			diff = now - which->trigger;
+			which->trigger = which->trigger + diff + snooze_secs;
+			which->offset  = which->offset - diff - snooze_secs;
+			alarm_add (which, &calendar_notify, data);
+			break;
+		default:
+			stop_beeping (GTK_OBJECT (w), NULL);
+			break;
+		}
+		
+		gtk_widget_unref (w);
 		return;
 	}
 
@@ -439,11 +485,26 @@ calendar_notify (time_t time, CalendarAlarm *which, void *data)
 		GtkWidget *w;
 		char *msg;
 
+		if (beep_on_display)
+			gdk_beep ();
 		msg = g_strconcat (_("Reminder of your appointment at "),
 					ctime (&app), "`",
 					ico->summary, "'", NULL);
-		w = gnome_message_box_new (msg, GNOME_MESSAGE_BOX_INFO, "Ok", NULL);
-		gtk_widget_show (w);
+		w = gnome_message_box_new (msg, GNOME_MESSAGE_BOX_INFO, 
+					   _("Ok"), snooze_button, NULL);
+		ret = gnome_dialog_run (GNOME_DIALOG (w));
+		switch (ret) {
+		case 1:
+			now = time (NULL);
+			diff = now - which->trigger;
+			which->trigger = which->trigger + diff + snooze_secs;
+			which->offset  = which->offset - diff - snooze_secs;
+			alarm_add (which, &calendar_notify, data);
+			break;
+		default:
+			break;
+		}
+		
 		return;
 	}
 }
@@ -460,11 +521,11 @@ mark_gtk_calendar_day (iCalObject *obj, time_t start, time_t end, void *c)
 
 	tm_s = *localtime (&start);
 	day_end = time_day_end (end);
-	
+
 	for (t = start; t <= day_end; t += 60*60*24){
 		time_t new = mktime (&tm_s);
 		struct tm tm_day;
-		
+
 		tm_day = *localtime (&new);
 		gtk_calendar_mark_day (gtk_cal, tm_day.tm_mday);
 		tm_s.tm_mday++;
@@ -537,14 +598,14 @@ gnome_calendar_colors_changed (GnomeCalendar *gcal)
 	todo_list_properties_changed (GNCAL_DAY_PANEL (gcal->day_view));
 }
 
-void 
-gnome_calendar_todo_properties_changed (GnomeCalendar *gcal) 
+void
+gnome_calendar_todo_properties_changed (GnomeCalendar *gcal)
 {
 	g_return_if_fail (gcal != NULL);
 	g_return_if_fail (GNOME_IS_CALENDAR (gcal));
-	
+
 	/* FIXME: add day and week view when they are done */
-	
+
 	todo_style_changed = 1;
 	todo_list_properties_changed (GNCAL_DAY_PANEL (gcal->day_view));
 }
