@@ -9,6 +9,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <libgnorba/gnorba.h>
 #include <pwd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -21,7 +22,7 @@
 #include "gnome-cal.h"
 #include "main.h"
 #include "timeutil.h"
-
+#include "corba-cal-factory.h"
 
 #define COOKIE_USER_HOME_DIR ((char *) -1)
 
@@ -61,9 +62,9 @@ struct color_prop color_props[] = {
 	{ 0xd364, 0xc6b7, 0x7969, N_("Highlighted day:"),      "/calendar/Colors/prelight_bg" },
 	{ 0x01f0, 0x01f0, 0x01f0, N_("Day numbers:"),          "/calendar/Colors/day_fg" },
 	{ 0x0000, 0x0000, 0xffff, N_("Current day's number:"), "/calendar/Colors/current_fg" },
- 	{ 0xbbbb, 0xbbbb, 0x0000, N_("To-Do item that is not yet due:"), "/calendar/Colors/todo_not_yet" },
- 	{ 0xdddd, 0xbbbb, 0x0000, N_("To-Do item that is due today:"),   "/calendar/Colors/todo_today" },
- 	{ 0xbbbb, 0xdddd, 0x0000, N_("To-Do item that is overdue:"),     "/calendar/Colors/todo_overdue" }
+	{ 0xbbbb, 0xbbbb, 0x0000, N_("To-Do item that is not yet due:"), "/calendar/Colors/todo_not_yet" },
+	{ 0xdddd, 0xbbbb, 0x0000, N_("To-Do item that is due today:"),   "/calendar/Colors/todo_today" },
+	{ 0xbbbb, 0xdddd, 0x0000, N_("To-Do item that is overdue:"),     "/calendar/Colors/todo_overdue" }
 };
 
 /* Number of active calendars */
@@ -72,8 +73,6 @@ int active_calendars = 0;
 /* A list of all of the calendars started */
 GList *all_calendars = NULL;
 
-static void new_calendar (char *full_name, char *calendar_file, char *geometry, char *view, gboolean hidden);
-
 /* For dumping part of a calendar */
 static time_t from_t, to_t;
 
@@ -86,6 +85,26 @@ static int show_events;
 /* If set, show todo items quit */
 static int show_todo;
 
+/* If set, beep on display alarms */
+gboolean beep_on_display = 0;
+
+/* If true, timeout the beeper on audio alarms */
+
+gboolean enable_aalarm_timeout = 0;
+guint audio_alarm_timeout = 0;
+const guint MAX_AALARM_TIMEOUT = 3600;
+const guint MAX_SNOOZE_SECS = 3600;
+gboolean enable_snooze = 0;
+guint snooze_secs = 60;
+
+/* Default values for alarms */
+CalendarAlarm alarm_defaults[4] = {
+	{ ALARM_MAIL, 0, 15, ALARM_MINUTES },
+	{ ALARM_PROGRAM, 0, 15, ALARM_MINUTES },
+	{ ALARM_DISPLAY, 0, 15, ALARM_MINUTES },
+	{ ALARM_AUDIO, 0, 15, ALARM_MINUTES }
+};
+
 static void
 init_username (void)
 {
@@ -104,6 +123,52 @@ range_check_hour (int hour)
 	return hour;
 }
 
+static void
+init_default_alarms (void)
+{
+	int i;
+	gboolean def;
+
+	alarm_defaults [ALARM_DISPLAY].type = ALARM_DISPLAY;
+	alarm_defaults [ALARM_AUDIO].type   = ALARM_AUDIO;
+	alarm_defaults [ALARM_PROGRAM].type = ALARM_PROGRAM;
+	alarm_defaults [ALARM_MAIL].type    = ALARM_MAIL;
+	
+	for (i = 0; i < 4; i++) {
+		switch (alarm_defaults [i].type) {
+		case ALARM_DISPLAY:
+			gnome_config_push_prefix ("/calendar/alarms/def_disp_");
+			break;
+		case ALARM_AUDIO:
+			gnome_config_push_prefix ("/calendar/alarms/def_audio_");
+			break;
+		case ALARM_PROGRAM:
+			gnome_config_push_prefix ("/calendar/alarms/def_prog_");
+			break;
+		case ALARM_MAIL:
+			gnome_config_push_prefix ("/calendar/alarms/def_mail_");
+			break;
+		}
+		
+		alarm_defaults[i].enabled = gnome_config_get_int ("enabled=0");
+		if (alarm_defaults[i].type != ALARM_MAIL) {
+			alarm_defaults[i].count   = gnome_config_get_int ("count=15");
+			alarm_defaults[i].units   = gnome_config_get_int ("units=0");
+		} else {
+			alarm_defaults[i].count   = gnome_config_get_int ("count=1");
+			alarm_defaults[i].count   = gnome_config_get_int ("count=2");
+		}
+		
+		alarm_defaults[i].data = gnome_config_get_string_with_default ("data=",
+									       &def);
+		if (def)
+			alarm_defaults[i].data = NULL;
+
+		gnome_config_pop_prefix ();
+	}
+}
+
+
 /*
  * Initializes the calendar internal variables, loads defaults
  */
@@ -161,11 +226,31 @@ init_calendar (void)
 	
 	todo_show_priority = gnome_config_get_bool("/calendar/Todo/show_priority");
 
+	/* read alarm settings */
+	beep_on_display = gnome_config_get_bool ("/calendar/alarms/beep_on_display=FALSE");
+	enable_aalarm_timeout = gnome_config_get_bool ("/calendar/alarms/enable_audio_timeout=FALSE");
+	audio_alarm_timeout = gnome_config_get_int ("/calendar/alarms/audio_alarm_timeout=60");
+	if (audio_alarm_timeout < 1)
+		audio_alarm_timeout = 1;
+	if (audio_alarm_timeout > MAX_AALARM_TIMEOUT)
+		audio_alarm_timeout = MAX_AALARM_TIMEOUT;
+	enable_snooze = gnome_config_get_bool ("/calendar/alarms/enable_snooze=FALSE");
+	snooze_secs = gnome_config_get_int ("/calendar/alarms/snooze_secs=300");
+	if (snooze_secs < 1)
+		snooze_secs = 1;
+	if (snooze_secs > MAX_SNOOZE_SECS)
+		snooze_secs = MAX_SNOOZE_SECS;
+
+	init_default_alarms ();
+	
+
 	/* Done */
 
 	gnome_config_pop_prefix ();
 }
 
+		
+	
 static void save_calendar_cmd (GtkWidget *widget, void *data);
 
 static void
@@ -176,6 +261,7 @@ about_calendar_cmd (GtkWidget *widget, void *data)
 		"Miguel de Icaza (miguel@kernel.org)",
 		"Federico Mena (federico@gimp.org)",
 		"Arturo Espinosa (arturo@nuclecu.unam.mx)",
+		"Russell Steinthal (rms39@columbia.edu)",
 		NULL
 	};
 
@@ -214,10 +300,29 @@ display_objedit_today (GtkWidget *widget, GnomeCalendar *gcal)
 	gtk_widget_show (ee);
 }
 
+GnomeCalendar *
+gnome_calendar_locate (const char *pathname)
+{
+	GList *l;
+
+	if (pathname == NULL || pathname [0] == 0)
+		pathname = user_calendar_file;
+	
+	for (l = all_calendars; l; l = l->next){
+		GnomeCalendar *gcal = l->data;
+
+		if (strcmp (gcal->cal->filename, pathname) == 0){
+			return gcal;
+		}
+	}
+	return NULL;
+}
+
 static void
 close_cmd (GtkWidget *widget, GnomeCalendar *gcal)
 {
 	all_calendars = g_list_remove (all_calendars, gcal);
+
 	if (gcal->cal->modified){
 		if (!gcal->cal->filename)
 			save_calendar_cmd (widget, gcal);
@@ -228,8 +333,10 @@ close_cmd (GtkWidget *widget, GnomeCalendar *gcal)
 	gtk_widget_destroy (GTK_WIDGET (gcal));
 	active_calendars--;
 
-	if (active_calendars == 0)
+	if (active_calendars == 0){
+		unregister_calendar_services ();
 		gtk_main_quit ();
+	}
 }
 
 void
@@ -370,15 +477,14 @@ static void
 save_ok (GtkWidget *widget, GtkFileSelection *fs)
 {
 	GnomeCalendar *gcal;
+	gchar *fname;
 
 	gcal = GNOME_CALENDAR (gtk_object_get_user_data (GTK_OBJECT (fs)));
 	gtk_window_set_wmclass (GTK_WINDOW (gcal), "gnomecal", "gnomecal");
 
-	if (gcal->cal->filename)
-		g_free (gcal->cal->filename);
-
-	gcal->cal->filename = g_strdup (gtk_file_selection_get_filename (fs));
-	calendar_save (gcal->cal, gcal->cal->filename);
+	fname = g_strdup (gtk_file_selection_get_filename (fs));
+	calendar_save (gcal->cal, fname);
+	g_free(fname);
 	gtk_main_quit ();
 }
 
@@ -448,7 +554,6 @@ save_calendar_cmd (GtkWidget *widget, void *data)
 			g_free (str);
 			gnome_dialog_set_default (GNOME_DIALOG (box), 1);
 			b = gnome_dialog_run (GNOME_DIALOG (box));
-			gtk_object_destroy (GTK_OBJECT (box));
 
 			if (b != 0)
 				return;
@@ -579,7 +684,7 @@ calendar_close_event (GtkWidget *widget, GdkEvent *event, GnomeCalendar *gcal)
 	return TRUE;
 }
 
-static void
+GnomeCalendar *
 new_calendar (char *full_name, char *calendar_file, char *geometry, char *page, gboolean hidden)
 {
 	GtkWidget   *toplevel;
@@ -587,7 +692,8 @@ new_calendar (char *full_name, char *calendar_file, char *geometry, char *page,
 	int         xpos, ypos, width, height;
 
 	/* i18n: This "%s%s" indicates possession. Languages where the order is
-       the inverse should translate it to "%2$s%1$s". */
+	 * the inverse should translate it to "%2$s%1$s".
+	 */
 	g_snprintf(title, 128, _("%s%s"), full_name, _("'s calendar"));
 
 	toplevel = gnome_calendar_new (title);
@@ -634,6 +740,8 @@ new_calendar (char *full_name, char *calendar_file, char *geometry, char *page,
 	}
 	
 	gtk_widget_show (toplevel);
+
+	return GNOME_CALENDAR (toplevel);
 }
 
 static void
@@ -874,13 +982,23 @@ int
 main(int argc, char *argv[])
 {
 	GnomeClient *client;
+	CORBA_Environment ev;
 
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 
-	gnome_init_with_popt_table ("calendar", VERSION, argc, argv,
-				    options, 0, NULL);
+	CORBA_exception_init (&ev);
 
+	gnome_CORBA_init_with_popt_table (
+		"calendar", VERSION, &argc, argv,
+		options, 0, NULL, GNORBA_INIT_SERVER_FUNC, &ev);
+
+	orb = gnome_CORBA_ORB ();
+	poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references (orb, "RootPOA", &ev);
+	if (ev._major == CORBA_NO_EXCEPTION){
+		init_corba_server ();
+	}
+	
 	if (show_events)
 		dump_events ();
 	if (show_todo)
