@@ -610,7 +610,7 @@ extern void gnomecard_edit(GList *node)
 	gtk_box_pack_start(GTK_BOX(hbox), radio1, FALSE, FALSE, 0);
 	radio2 = gtk_radio_button_new_with_label(
 		gtk_radio_button_group(GTK_RADIO_BUTTON(radio1)),
-		_("X.509"));
+		_("X509"));
 	if (crd->key.prop.used && crd->key.type == KEY_X509)
 	  gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio2), 1);
 	my_connect(radio2, "toggled", box, &crd->key.prop, PROP_KEY);
@@ -699,7 +699,9 @@ colsetup_list_selected(GtkCList *list, gint row, gint column,
 
     g_message("User selected %s", getColumnNameFromType(coltype));
 
-    if (g_list_find(edit->selHdrs, GINT_TO_POINTER(coltype)))
+    if (coltype != COLTYPE_EMAIL &&
+	coltype != COLTYPE_PHONE &&
+	g_list_find(edit->selHdrs, GINT_TO_POINTER(coltype)))
 	gtk_widget_set_sensitive(edit->addButton, 0);
     else
 	gtk_widget_set_sensitive(edit->addButton, 1);
@@ -710,38 +712,47 @@ colsetup_list_selected(GtkCList *list, gint row, gint column,
 static void
 colsetup_addpress(GtkWidget *widget, gpointer data)
 {
-    ColumnHdrEditor *edit;
-    gint coltype;
-
-    edit = (ColumnHdrEditor *)data;
-    if (GTK_CLIST(edit->srcList)->selection) {
-	gint row, row2;
-	const gchar *rowtxt[2];
-
-	row = GPOINTER_TO_INT(GTK_CLIST(edit->srcList)->selection->data);
-
-	g_message("adding row # %d",row);
-
-	coltype = GPOINTER_TO_INT(gtk_clist_get_row_data(GTK_CLIST(edit->srcList), row));
-	g_message("coltype is %d",coltype);
-
-	/* add to end of the clist, selected list if not already selected */
-	if (!g_list_find(edit->selHdrs, GINT_TO_POINTER(coltype))) {
-	    edit->selHdrs=g_list_append(edit->selHdrs,(GINT_TO_POINTER(coltype)));
-	    rowtxt[0] = getColumnNameFromType(coltype);
-	    rowtxt[1] = NULL;
-	    row2=gtk_clist_append(GTK_CLIST(edit->destList), rowtxt);
-	    gtk_clist_set_row_data(GTK_CLIST(edit->destList),
-				   row2, GINT_TO_POINTER(coltype));
-
-	    /* disable add button */
-	    gtk_widget_set_sensitive(edit->addButton, 0);
-
-	    /* notify property box we've made a change */
-	    gnome_property_box_changed(edit->box);
+	ColumnHdrEditor *edit;
+	gint coltype;
+	
+	edit = (ColumnHdrEditor *)data;
+	if (GTK_CLIST(edit->srcList)->selection) {
+		gint row, row2;
+		const gchar *rowtxt[2];
+		
+		row = GPOINTER_TO_INT
+		  (GTK_CLIST(edit->srcList)->selection->data);
+		
+		g_message("adding row # %d",row);
+		
+		coltype = GPOINTER_TO_INT
+		  (gtk_clist_get_row_data(GTK_CLIST(edit->srcList), row));
+		g_message("coltype is %d",coltype);
+		
+		/* add to end of the clist, selected list if not already selected */
+		if (coltype == COLTYPE_EMAIL ||
+		    coltype == COLTYPE_PHONE ||
+		    !g_list_find(edit->selHdrs, GINT_TO_POINTER(coltype))) {
+			edit->selHdrs = g_list_append
+			  (edit->selHdrs,(GINT_TO_POINTER(coltype)));
+			
+			rowtxt[0] = getColumnNameFromType(coltype);
+			rowtxt[1] = NULL;
+			row2 = gtk_clist_append
+			  (GTK_CLIST(edit->destList), rowtxt);
+			gtk_clist_set_row_data(GTK_CLIST(edit->destList),
+					       row2, GINT_TO_POINTER(coltype));
+			
+			/* disable add button */
+			if (coltype != COLTYPE_EMAIL &&
+			    coltype != COLTYPE_PHONE)
+			  gtk_widget_set_sensitive(edit->addButton, 0);
+			
+			/* notify property box we've made a change */
+			gnome_property_box_changed(edit->box);
+		}
+		
 	}
-				      
-    }
 }
 
 static void
@@ -881,10 +892,9 @@ void
 gnomecard_setup(GtkWidget *widget, gpointer data)
 {
         static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
-	GtkWidget *vbox, *vbox2, *frame;
-	GtkWidget *label;
+	GtkWidget *hbox, *vbox, *vbox2, *frame;
+	GtkWidget *label, *h, *v;
 
-	GtkWidget *table;
 	GtkWidget *scrollwin;
 	GtkWidget *delButton;
 	GtkWidget *upButton;
@@ -916,58 +926,79 @@ gnomecard_setup(GtkWidget *widget, gpointer data)
 				 vbox, label);
 	
 	frame = gtk_frame_new(_("Column Display"));
-	gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, FALSE, GNOME_PAD_SMALL);
 	
-	table = my_gtk_table_new(3, 1);
-	gtk_container_add(GTK_CONTAINER(frame), table);
+	v = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
+	gtk_container_add(GTK_CONTAINER(frame), v);
+	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(v), hbox, TRUE, FALSE, GNOME_PAD_SMALL);
 
 	/* make list of possible columns to add */
 	frame = gtk_frame_new(_("Possible Columns"));
+	gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, GNOME_PAD_SMALL);
+	h = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
+	gtk_container_add(GTK_CONTAINER(frame), h);
+	v = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(h), v, TRUE, TRUE, GNOME_PAD_SMALL);
 	scrollwin = gtk_scrolled_window_new(NULL, NULL);
+	gtk_box_pack_start(GTK_BOX(v), scrollwin, TRUE, TRUE, GNOME_PAD_SMALL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
-	gtk_container_add(GTK_CONTAINER(frame), scrollwin);
 	edit->srcList = gtk_clist_new(1);
 	gtk_container_add(GTK_CONTAINER(scrollwin), edit->srcList);
-	gtk_widget_set_usize(edit->srcList, 200, 200);
 	gtk_clist_set_selection_mode(GTK_CLIST(edit->srcList),
 				     GTK_SELECTION_BROWSE);
-	gtk_clist_set_column_auto_resize(GTK_CLIST(edit->srcList), 0, 1);
-	gtk_table_attach(GTK_TABLE(table), frame, 0, 1, 0, 1,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
+	gtk_clist_set_column_auto_resize(GTK_CLIST(edit->srcList), 0, TRUE);
+	gtk_widget_set_usize (GTK_WIDGET(edit->srcList), 0, 180);
+
+	/* add add/remove buttons in center */
+	align = gtk_alignment_new(0.5, 0.5, 0, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), align, TRUE, FALSE, GNOME_PAD_SMALL);
+	vbox2 = gtk_vbox_new(TRUE, 0);
+	gtk_container_add(GTK_CONTAINER(align), vbox2);
+	
+	edit->addButton = gnome_pixmap_button (gnome_stock_pixmap_widget 
+	   (vbox2, GNOME_STOCK_PIXMAP_ADD), _("Add"));
+	delButton = gnome_pixmap_button (gnome_stock_pixmap_widget 
+	   (vbox2, GNOME_STOCK_PIXMAP_REMOVE), _("Remove"));
+	gtk_box_pack_start(GTK_BOX(vbox2), 
+			   edit->addButton, FALSE, FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(vbox2), 
+			   delButton, FALSE, FALSE, GNOME_PAD_SMALL);
 
 	/* make list of currently displayed column types */
-	frame=gtk_frame_new(_("Displayed Columns"));
+	frame = gtk_frame_new(_("Displayed Columns"));
+	gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, GNOME_PAD_SMALL);
+	h = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
+	gtk_container_add(GTK_CONTAINER(frame), h);
+	v = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(h), v, TRUE, TRUE, GNOME_PAD_SMALL);
 	scrollwin = gtk_scrolled_window_new(NULL, NULL);
+	gtk_box_pack_start(GTK_BOX(v), scrollwin, TRUE, TRUE, GNOME_PAD_SMALL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
-	gtk_container_add(GTK_CONTAINER(frame), scrollwin);
 	edit->destList = gtk_clist_new(1);
 	gtk_container_add(GTK_CONTAINER(scrollwin), edit->destList);
-	gtk_widget_set_usize(edit->destList, 200, 200);
 	gtk_clist_set_selection_mode(GTK_CLIST(edit->destList),
 				     GTK_SELECTION_BROWSE);
-	gtk_clist_set_column_auto_resize(GTK_CLIST(edit->destList), 0, 1);
-	gtk_table_attach(GTK_TABLE(table), frame, 2, 3, 0, 1,
-			 GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
+	gtk_clist_set_column_auto_resize (GTK_CLIST(edit->destList), 0, TRUE);
 	
-	/* add add/remove buttons in center */
-	edit->addButton = gtk_button_new_with_label(_("Add"));
-	delButton = gtk_button_new_with_label(_("Remove"));
-	upButton = gtk_button_new_with_label(_("Move Up"));
-	dnButton = gtk_button_new_with_label(_("Move Dn"));
-
-	align = gtk_alignment_new(0.0, 0.5, 0, 0);
-	vbox2 = gtk_vbox_new(TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox2), edit->addButton, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox2), delButton, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox2), upButton, FALSE, FALSE, 6);
-	gtk_box_pack_start(GTK_BOX(vbox2), dnButton, FALSE, FALSE, 0);
-	gtk_container_add(GTK_CONTAINER(align), vbox2);
-	gtk_table_attach(GTK_TABLE(table), align, 1, 2, 0, 1, 0, 0, 5, 5);
+	h = gtk_hbox_new(TRUE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(v), h, FALSE, FALSE, GNOME_PAD_SMALL);
+	upButton = gtk_button_new ();
+	gtk_container_add (GTK_CONTAINER (upButton),
+			   gnome_stock_pixmap_widget
+			   (vbox2, GNOME_STOCK_PIXMAP_UP));
+	gtk_box_pack_start(GTK_BOX(h), upButton, FALSE, FALSE, GNOME_PAD_SMALL);
+	dnButton = gtk_button_new ();
+	gtk_container_add (GTK_CONTAINER (dnButton),
+			   gnome_stock_pixmap_widget
+			   (vbox2, GNOME_STOCK_PIXMAP_DOWN));
+	gtk_box_pack_start(GTK_BOX(h), dnButton, FALSE, FALSE, GNOME_PAD_SMALL);
 
+	
 	/* fill in the two lists */
 	edit->allHdrs = getAllColumnHdrs();
 	for (l=edit->allHdrs, i=0; l; l=l->next, i++) {
@@ -1303,22 +1334,16 @@ static void gnomecard_find_card(GtkWidget *w, gpointer data)
 						sens))
 			found = 1;
 		
-#if 0			
 		for (k = crd->email.l; k && !found; k = k->next)
 		    if (gnomecard_match_pattern(pattern, 
 						((CardEMail *) k->data)->data,
 						sens))
 			found = 1;
-#else
-		g_message("Did not search of email (yet)");
-#endif
 		
-/* NOT IMPLEMENTED
 		for (k = crd->dellabel.l; k && !found; k = k->next)
 		    if (gnomecard_match_pattern(pattern, 
 						((CardDelLabel *)k->data)->data, sens))
 			found = 1;
-*/		
 
 		for (k = crd->deladdr.l; k && !found; k = k->next)
 		    for (i = 0; i < DELADDR_MAX; i++)
