@@ -66,7 +66,7 @@ impl_gnome_PIM_vCard_server__create(PortableServer_POA poa,
 GnomeApp *gnomecard_window;
 
 GtkCList *gnomecard_list=NULL;
-GtkWidget *cardlist_scrollwin=NULL; /* scrollwin for cardlist */
+GtkWidget *cardlist_scrollwin = NULL;
 
 gint     gnomecard_selected_row=0;
 GtkWidget *tb_next, *tb_prev, *tb_first, *tb_last;
@@ -74,8 +74,6 @@ GtkWidget *tb_edit, *tb_find, *tb_save, *tb_del;
 GtkWidget *menu_next, *menu_prev, *menu_first, *menu_last;
 GtkWidget *menu_edit, *menu_find, *menu_save, *menu_del;
 
-/* NOT USED GnomeUIInfo *add_menu;  */
-
 GList *gnomecard_crds=NULL;
 GList *gnomecard_curr_crd=NULL;
 
@@ -180,7 +178,6 @@ gnomecard_set_prev(gboolean state)
 static void
 list_button_press(GtkWidget * widget, GdkEventButton *event)
 {
-    g_message("In list_button_press");
 }
 
 
@@ -422,9 +419,17 @@ void gnomecard_last_card(GtkWidget *widget, gpointer data)
 
 void gnomecard_quit(GtkWidget *widget, gpointer data)
 {
-	if (gnomecard_destroy_cards()) {
+	if (gnomecard_destroy_cards ()) {
+		int x, y;
+	
+		x = GTK_WIDGET (gnomecard_window)->allocation.width;
+		y = GTK_WIDGET (gnomecard_window)->allocation.height;
+		gnome_config_set_int("/GnomeCard/CardDisplay/width", x);
+		gnome_config_set_int("/GnomeCard/CardDisplay/height", y);
+		gnome_config_sync ();
+		
 		gtk_widget_destroy(GTK_WIDGET (gnomecard_window));
-		gtk_main_quit();
+		gtk_main_quit ();
 	}
 }
 
@@ -694,10 +699,10 @@ void gnomecard_sort_by_fname(GtkWidget *w, gpointer data)
 
 void gnomecard_init(void)
 {
+	GtkWidget *scrollwin;
         GnomeAppBar *appbar;
-	GtkWidget *canvas, *align, *hbox, *hbox1, *hbox2;
-	GtkWidget *table, *w;
-	gint ncol, i;
+	GtkWidget *canvas, *hbox;
+	gint ncol, i, x, y;
 
 	/* hard coded column headers */
 	ColumnType defaulthdrs[] = {COLTYPE_CARDNAME, COLTYPE_EMAIL, 
@@ -707,7 +712,11 @@ void gnomecard_init(void)
 	gnomecard_init_stock();
 	gnomecard_init_pixes();
 	
-	gnomecard_window = GNOME_APP(gnome_app_new("GnomeCard", "GnomeCard: Default"));
+	gnomecard_window = GNOME_APP(gnome_app_new("GnomeCard", 
+						   "GnomeCard: Default"));
+	x = gnome_config_get_int("/GnomeCard/CardDisplay/width=0");
+	y = gnome_config_get_int("/GnomeCard/CardDisplay/height=0");
+	gtk_widget_set_usize (GTK_WIDGET (gnomecard_window), x, y);
 
 	appbar = GNOME_APPBAR(gnome_appbar_new(FALSE, TRUE,
 					       GNOME_PREFERENCES_USER));
@@ -716,23 +725,26 @@ void gnomecard_init(void)
 
 	gtk_window_set_wmclass(GTK_WINDOW(gnomecard_window), "GnomeCard",
 			       "GnomeCard");
-	gtk_window_set_policy(GTK_WINDOW(gnomecard_window), TRUE, TRUE, TRUE);
+	gtk_window_set_policy(GTK_WINDOW(gnomecard_window), TRUE, TRUE, FALSE);
 			      
 	gtk_signal_connect(GTK_OBJECT(gnomecard_window), "delete_event",
 			   GTK_SIGNAL_FUNC(gnomecard_delete), NULL);
 	
 	hbox = gtk_hbox_new(FALSE, 0);
-
+/*	gtk_paned_set_gutter_size (GTK_PANED (hpaned), GNOME_PAD_BIG);
+	gtk_widget_show (hpaned);*/
+	
 	gnome_app_create_menus(GNOME_APP(gnomecard_window), mainmenu);
 
 	gnome_app_install_menu_hints(GNOME_APP(gnomecard_window), mainmenu);
 	gnome_app_create_toolbar(GNOME_APP(gnomecard_window), toolbar);
 
 	gnome_app_set_contents(GNOME_APP(gnomecard_window), hbox);
+/*	gnome_app_set_contents(GNOME_APP(gnomecard_window), hpaned);*/
 
-	cardlist_scrollwin = gtk_scrolled_window_new(NULL, NULL);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(cardlist_scrollwin),
-				   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	cardlist_scrollwin = scrollwin = gtk_scrolled_window_new(NULL, NULL);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin),
+				   GTK_POLICY_ALWAYS, GTK_POLICY_ALWAYS);
 
 	/* card display layout */
 	ncol=gnome_config_get_int("/GnomeCard/CardDisplay/ncols=0");
@@ -742,7 +754,6 @@ void gnomecard_init(void)
 	    hdrs = g_new0(ColumnType, ncol+1);
 	    for (p=hdrs, i=0; i<ncol; i++) {
 		gchar path[200];
-		gint  coltype;
 		gchar *s;
 
 		snprintf(path, sizeof(path),
@@ -757,46 +768,30 @@ void gnomecard_init(void)
 	    gnomecard_list = GTK_CLIST(gnomecardCreateCardListDisplay(hdrs));
 	}
 
-	gtk_container_add(GTK_CONTAINER(cardlist_scrollwin), GTK_WIDGET(gnomecard_list));
-	gtk_signal_connect(GTK_OBJECT(cardlist_scrollwin),
+	gtk_container_add(GTK_CONTAINER(scrollwin), GTK_WIDGET(gnomecard_list));
+	gtk_signal_connect(GTK_OBJECT(scrollwin),
 			  "button_press_event",
 			  GTK_SIGNAL_FUNC(list_button_press),
 			  NULL);
-	gtk_widget_show(cardlist_scrollwin);
-				       
+/*	gtk_widget_set_usize (scrollwin, 200, 0);*/
+	gtk_widget_show(scrollwin);
+	
 	gtk_box_pack_start(GTK_BOX(hbox), cardlist_scrollwin, TRUE, TRUE, 0);
+/*	gtk_paned_pack1 (GTK_PANED (hpaned), scrollwin, TRUE, FALSE);*/
 
-	/* add canvas with some scrollbars */
+	/* add canvas */
 	gtk_widget_push_visual(gdk_imlib_get_visual());
 	gtk_widget_push_colormap(gdk_imlib_get_colormap());
 	
 	canvas = gnomecard_canvas_new();
-	table = gtk_table_new(2, 2, FALSE);
-	gtk_table_set_row_spacings(GTK_TABLE(table), 4);
-	gtk_table_set_col_spacings(GTK_TABLE(table), 4);
-	gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 0);
-
-	gtk_table_attach(GTK_TABLE(table), canvas, 0, 1, 0, 1,
-			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
-			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
-			 0, 0);
-
-	w = gtk_hscrollbar_new (GTK_LAYOUT (canvas)->hadjustment);
-        gtk_table_attach (GTK_TABLE (table), w,
-                          0, 1, 1, 2,
-                          GTK_EXPAND | GTK_FILL | GTK_SHRINK,
-                          GTK_FILL,
-                          0, 0);
-        gtk_widget_show (w);
-        w = gtk_vscrollbar_new (GTK_LAYOUT (canvas)->vadjustment);
-        gtk_table_attach (GTK_TABLE (table), w,
-                          1, 2, 0, 1,
-                          GTK_FILL,
-                          GTK_EXPAND | GTK_FILL | GTK_SHRINK,
-                          0, 0);
-        gtk_widget_show (w);
+	scrollwin = gtk_scrolled_window_new(NULL, NULL);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin),
+				   GTK_POLICY_ALWAYS, GTK_POLICY_ALWAYS);
+	gtk_container_add(GTK_CONTAINER(scrollwin), canvas);
 	gtk_widget_show(canvas);
-	gtk_widget_show(table);
+	gtk_widget_show(scrollwin);
+	gtk_box_pack_start(GTK_BOX(hbox), scrollwin, FALSE, FALSE, 0);
+/*	gtk_paned_pack2 (GTK_PANED (hpaned), scrollwin, TRUE, TRUE);*/
 
 	/* no cards yet */
 	gnomecard_crds = NULL;
@@ -830,7 +825,6 @@ void gnomecard_init(void)
 	  gnomecard_set_curr(NULL);
 
 	gtk_widget_show(GTK_WIDGET (gnomecard_window));
-
 }
 
 int main (int argc, char *argv[])
@@ -841,7 +835,6 @@ int main (int argc, char *argv[])
 	CORBA_Object name_server;
 	PortableServer_POA poa;
 	PortableServer_POAManager pm;
-	gchar *ior;
 
         bindtextdomain(PACKAGE, GNOMELOCALEDIR);
 	textdomain(PACKAGE);
